@@ -8,13 +8,17 @@ package Net::SMTPS;
 
 use vars qw ( $VERSION @ISA );
 
-$VERSION = "0.05";
+$VERSION = '0.07';
 
+use strict;
 use base qw ( Net::SMTP );
 use Net::Cmd;  # import CMD_OK, CMD_MORE, ...
 use Net::Config;
 
 eval {
+    require IO::Socket::IP
+	and unshift @ISA, 'IO::Socket::IP';
+} or eval {
     require IO::Socket::INET6
 	and unshift @ISA, 'IO::Socket::INET6';
 } or do {
@@ -22,8 +26,6 @@ eval {
 	and unshift @ISA, 'IO::Socket::INET';
 };
 
-use strict;
-
 # Override to support SSL/TLS.
 sub new {
   my $self = shift;
@@ -116,15 +118,16 @@ sub new {
   }
 
 # STARTTLS
-  if (defined($ssl) && $ssl =~ /starttls/i && $obj->supports('STARTTLS') ) {
-    (($obj->command('STARTTLS')->response() == CMD_OK)
-     and $obj->ssl_start(\%ssl_args)
-     and $obj->hello($arg{Hello} || ""))
-       or do {
-	 $obj->set_status(500, ["Cannot start SSL session"]);
-	 $obj->close();
-	 return undef;
-       };
+  if (defined($ssl) && $ssl =~ /starttls/i && defined($obj->supports('STARTTLS')) ) {
+      #123006 $obj->supports('STARTTLS') returns '' issue.
+      (($obj->command('STARTTLS')->response() == CMD_OK)
+       and $obj->ssl_start(\%ssl_args)
+       and $obj->hello($arg{Hello} || ""))
+	  or do {
+	      $obj->set_status(500, ["Cannot start SSL session"]);
+	      $obj->close();
+	      return undef;
+      };
   }
 
   $obj;
@@ -143,28 +146,37 @@ sub ssl_start {
 
 # Override to specify a certain auth mechanism.
 sub auth {
-  my ($self, $username, $password, $mech) = @_;
+    my ($self, $username, $password, $mech) = @_;
 
-  if ($mech) {
-      $self->debug_print(1, "my favorite: ". $mech . "\n") if $self->debug;
+    if ($mech) {
+	$self->debug_print(1, "my favorite: ". $mech . "\n") if $self->debug;
 
-      my @cl_mech = split /\s+/, $mech;
-      my @matched = ();
-      if (exists ${*$self}{'net_smtp_esmtp'}->{'AUTH'}) {
-	  my $sv = ${*$self}{'net_smtp_esmtp'}->{'AUTH'};
-	  foreach my $i (@cl_mech) {
-	      if (index($sv, $i) >= 0 && grep(/$i/i, @matched) == () ) {
-		  push @matched, uc($i);
-	      }
-	  }
-      }
-      if (@matched) {
-	  ## override AUTH mech as specified.
-	  ## if multiple mechs are specified, priority is still up to Authen::SASL module.
-	  ${*$self}{'net_smtp_esmtp'}->{'AUTH'} = join " ", @matched;
-      }
-  }
-  $self->SUPER::auth($username, $password);
+	my @cl_mech = split /\s+/, $mech;
+	my @matched = ();
+	if (exists ${*$self}{'net_smtp_esmtp'}->{'AUTH'}) {
+	    my $sv = ${*$self}{'net_smtp_esmtp'}->{'AUTH'};
+	    $self->debug_print(1, "AUTH-server offerred: ". $sv . "\n") if $self->debug;
+
+	    foreach my $i (@cl_mech) {
+		if (index($sv, $i) >= 0 && grep(/$i/i, @matched) == () ) {
+		    push @matched, uc($i);
+		}
+	    }
+	}
+	if (@matched) {
+	    ## override AUTH mech as specified.
+	    ## if multiple mechs are specified, priority is still up to Authen::SASL module.
+	    ${*$self}{'net_smtp_esmtp'}->{'AUTH'} = join " ", @matched;
+	    $self->debug_print(1, "AUTH-negotiated: ". ${*$self}{'net_smtp_esmtp'}->{'AUTH'} . "\n") if $self->debug;
+	}
+    }
+    $self->SUPER::auth($username, $password);
+}
+
+# Fix #121006 no timeout issue.
+sub getline {
+    my $self = shift;
+    $self->Net::Cmd::getline(@_);
 }
 
 1;
